**Hello! Iam axeinstd, and this is simple_num_operations package!**
**There is GitHub page with documentation! https://github.com/thedotaxein/simplenumoperations**
# Version 1rc0 (1 pre-release) now!
## license axeinstd, MIT LICENSE!